Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootrootCmd.
func GenerateCmd ¶
Types ¶
type Options ¶
type Options struct {
ConfigFlags *genericclioptions.ConfigFlags
PrintFlags *genericclioptions.PrintFlags
// The URL that the ingress can be targeted at after
// it is deployed
URL string
// The prefix for the Ingress object name
IngressObjectNamePrefix string
// The path which will trigger the exploit
RedirectPath string
// CloseItOffPath is the path used to close off the exploit. There's no reason to
// target this path but without it the nginx config will be invalid
CloseItOffPath string
// ExploitCommand is the command which will be executed on the ingress-nginx controller pod
ExploitCommand string
genericiooptions.IOStreams
}
Click to show internal directories.
Click to hide internal directories.